*===================================*
*		Hourly wage vars			*
*===================================* 

* Recovers variables related to earnings and hours worked.

*IMPORTANT:
* Net Wages: are only available for a few countries.
* Hours: includes ALL hours worked in the reference month (October) 
* Two hourly wage measures with (without) bonus and extra-hours. 

 
version 14

cd "$dofiles"
global dofiles  "`c(pwd)'"
global original "$dofiles\..\original data\"
global correct 	"$dofiles\..\data"

cd "$correct"

local files: dir . files "*.dta"
foreach file in `files'{
		
	tokenize `file', parse("_",".")
	local yy	"`5'"
	local cc	"`7'"
 	
	use "`file'", clear
	
	* Hour related vars
	*--------------------*
	capture drop hours
	gen hours = b32
	label var hours "Hours worked in last month -- inc. overtime"

	capture drop hours_over
	gen hours_over = b321
	label var hours_over "Hours worked (overtime) last month"
	
	capture drop overt
	gen overt = b321>0
	
 	capture drop weeks
	gen weeks = b31
	label var weeks "Weeks worked in the reference year"
		
	* Earnings
	*----------------------*
	
	capture drop gross_wage
	gen gross_wage2 = 	b42 - b421 
	if ("`cc'" =="pl" & year==2002) | ("`cc'" =="nl" & year==2006) {
			replace gross_wage = 	b42 - b421 
	}
	
	capture drop net_wage
	gen net_wage 	=	b42 - b423  if (b42 - b423>0)
		
	
	*	Hourly wages
	*----------------------*
	
	capture drop hwage 
	gen hwage  = b43
	label var hwage  "Average gross hourly wages - ses produced"
	
	if "`cc'" =="de" & `yy' >2006{
		replace hwage = subinstr(hwage,",",".",.)
		destring hwage, replace
	} 
	
	capture drop hwage_own
	gen hwage_own = gross_wage/(hours-hours_over)
	label var hwage_own "Gross hourly wage: bonus & overtime not included"
	
	
	*	Possible errors
	*---------------------------*
	
	capture drop flag_wage
	gen flag_wage = 0 
	replace flag_wage =1 if gross_wage<0
	replace flag_wage =2 if hours<hours_over
	replace flag_wage =3 if hours<hours_over & gross_wage<0
	
	capture label drop errs
	label define errs 1 "bonus > reg wage" 2 "hours<extra hours" 3 "both"
	label val flag_wage errs
	label var flag_wage "Possible errors in hourly wages"
	
	save, replace
	}
	
 
