*===================================*
*		Firm characteristics		*
*===================================* 
 
* IMPORTANT: 
* Firm size varies by country, so the coding is not to be used in a fast-loop. Instead use size_50. 
* INDUSTRY coding: there are two NACE variables: Rev 1 (2002-2006) and Rev 2 (2010-2014).
* moreover, they are not fully comparable. In Germany (2006 and 2010) some codes were merged
* Industry is consistent, but very aggregated. 
* version 1.1: nace added for Italy
* Private ownership added for  Italy 2010
 
 version 14


cd "$dofiles"
global dofiles  "`c(pwd)'"
global original "$dofiles\..\original data\"
global correct 	"$dofiles\..\data"
cd "$correct"

local files: dir . files "*.dta"
foreach file in `files'{
		
	tokenize `file', parse("_",".")
	local yy 	"`5'"
	local cc 	"`7'"
 
	** EXCEPTIONS
	if "`cc'"=="it" & `yy'== 2010 continue

	** Working files
	use "`file'",clear

	* ID
	capture drop unit_id
	gen unit_id = key_l
	
	* Ownership
	*------------------------------
	capture drop private
	capture drop pub
	
	if "`cc'"=="lu" & `yy' ==2010 tostring a14, replace	// -- all missing
	gen private = a14=="B" if a14!=""
	label var private "Private ownership > 50%"
	
	gen pub = a14 =="A" if !missing(a14)
	
	
	* Size
	*------------------------------
	capture drop size_*
	encode a12_class, gen(size_firm)
	capture label var size_firm "Firm size"
	
	if  "`cc'"=="uk" & `yy' ==2010 gen size_50 = (a12=="1" |a12=="2") & a12!="U"
	else gen size_50 = a12>0 if a12!=4
	label var size_50 "Over 50 employees"
		
	gen size_unit = a16 if a16<1000000
	label var size_unit "Size of local unit"
	
	local var a12_class	
	capture drop size_d
	gen size_d	 = .

	replace size_d = 1 if inlist(`var',"1_49", "0_9", "10_49")
	replace size_d = 2 if inlist(`var' ,"50_249", "LT_249")
	replace size_d = 3 if inlist(`var',"GT_50", "GT_250","250_999","GT_1000")
	replace size_d = 3 if inlist(`var',"GT_250", "GT_500","50_1000")
	replace size_d = 4 if `var'!= "" & size_d ==.

	label def size_d 1 "Under 50" 2 "50 to 249" 3 "Over 250" 4 "Unknown" , modify
	label val size_d size_d

	qui gen large = size_d==3
	
	save, replace
}


	
	
* Industry (gross)
*---------------------------------

*
capture program drop label_inds
program label_inds
	capture label drop ind
	label def ind 1 "Agriculture" 2 "Mining, manufacture, elec" ///
				3 "Construction" 4 "Mkt-services" 5 "Non-mkt serv"
	label val industry ind
	label var industry "Industry -- gross grouping"
end
* 
	
local files: dir . files "*.dta"
foreach file in `files'{

	tokenize `file', parse("_",".")
	local yy 	"`5'"
	local cc 	"`7'"
 
	** EXCEPTIONS
	if  inlist("`cc'","it","de") & inlist(`yy',2006,2010) continue

 
	use "`file'",clear

	capture drop industry
		
	if `yy'<2010{
	capture drop nace_1
	gen nace_1 = nace
	label var nace_1 "NACE rev 1"

	gen industry = 1 		if nace!=""
	replace industry = 2	if inlist(nace,"C","D","E")
	replace industry = 3	if nace=="F"
	replace industry = 4	if nace>"F" & nace <"L" 
	replace industry = 5	if nace>"K" & nace!=""
			}
		
	if `yy'>2006{
	capture drop nace_2
	gen nace_2 = substr(nace,2,1)
	label var nace_2 "NACE rev 2"
	
	gen industry = 1 		if nace_2!=""
	replace industry = 2	if inlist(nace_2,"B","C","D","E")
	replace industry = 3	if nace_2=="F"
	replace industry = 4	if nace_2>"F" & nace_2 <"O" 
	replace industry = 5	if nace_2>"M" & nace_2!=""
			}
		
	label_inds
	
	save, replace
	}
 
** EXCEPTIONS

* ITALY -- 2006
use "$correct\eu_ses_2006_it", clear

capture drop industry
gen industry = real(substr(a13,2,3))
recode industry (1/41=2)(45=3)(50/74=4)(75/93=5) 

	capture drop nace
	gen x = real(substr(a13,2,2))
		gen nace  = "C"
		replace nace = "D" if inrange(x, 15,39)
		replace nace = "E" if inrange(x, 40,44)
		replace nace = "F" if inrange(x, 45,49)
		replace nace = "G" if inrange(x, 50,54)
		replace nace = "H" if inrange(x, 55,59)
		replace nace = "I" if inrange(x, 60,64)
		replace nace = "J" if inrange(x, 65,69)
		replace nace = "K" if inrange(x, 70,74)
		replace nace = "L" if inrange(x, 75,79)
		replace nace = "M" if inrange(x, 80,84)
		replace nace = "N" if inrange(x, 85,89)
		replace nace = "O" if inrange(x, 90,93)
		capture drop x
		
label_inds

save , replace

*ITALY 2010

use "$correct\eu_ses_2010_it", clear

capture drop size_*
encode a12, gen(size_firm)
capture label var size_firm "Firm size"
	
gen size_50 = a12!="10-49" if a12!="ALL"
label var size_50 "Over 50 employees"
		
gen size_unit = a16 
label var size_unit "Size of local unit"

local var a16
gen size_d	 = .

replace size_d = 1 if inlist(`var',"1_49", "0_9", "10_49")
replace size_d = 2 if inlist(`var' ,"50_249", "LT_249")
replace size_d = 3 if inlist(`var',"GT_50", "GT_250","250_999","GT_1000")
replace size_d = 3 if inlist(`var',"GT_250", "GT_500","50_1000")
replace size_d = 4 if `var'!= "" & size_d ==.

label def size_d 1 "Under 50" 2 "50 to 249" 3 "Over 250" 4 "Unknown" , modify
label val size_d size_d

qui gen large = size_d==3
	
capture drop industry
gen industry = real(substr(a13,2,3))
recode industry (10/39=2) (.=2)(41/43=3)(45/82=4)(84/96=5) 

label_inds

capture drop aux
gen aux = real(subinstr(a13,"X","",.))

recode aux  (10/33=1) (35=2) (36/39=3) (41/43=4) (45/47=5) (49/53=6) ///
			(55/56=7) (58/63=8) (64/66=9) (68=10) (69/75=11) (77/82=12) ///
			(84=13) (85=14) (86/88=15) (90/93=16) (94/96=17) (97/98=18) (99=19), gen(xl)  

gen nace ="XB" if a13=="XB " 
local i =1
foreach c in `c(ALPHA)'{
if "`c'">"U" | "`c'"<"C" continue
quiet replace nace = "X`c'" if xl==`i'
local ++i

}
			
drop aux xl  

gen private = a14=="B" if a14!=""
label var private "Private ownership > 50%"
	
	
save, replace

* GERMANY 2006
use "$correct\eu_ses_2006_de", clear

capture drop nace_1
gen nace_1 = a13
replace nace_1 = "D" if strpos(nace_1,"20")!=0
replace nace_1 = "D" if strpos(nace_1,"30")!=0
replace nace_1 = "D" if strpos(nace_1,"D")!=0
replace nace_1 = "G" if strpos(nace_1,"50")!=0 |nace_1=="52"
replace nace_1 = "I" if strpos(nace_1,"60")!=0 | strpos(nace_1,"63")!=0 
replace nace_1 = "K" if strpos(nace_1,"70")!=0 | nace_1=="74"
replace nace_1 = "O" if strpos(nace_1,"92")!=0 | nace_1=="90" | nace_1=="91"
	
capture drop industry
gen industry = 1 		if nace_1!=""
replace industry = 2	if inlist(nace_1,"C","D","E")
replace industry = 3	if nace_1=="F"
replace industry = 4	if nace_1>"F" & nace_1 <"L" 
replace industry = 5	if nace_1>"K" & nace_1!=""

label_inds

save, replace


* GERMANY 2010
use "$correct\eu_ses_2010_de", clear
capture drop nace_2
gen nace_2 = a13
replace nace_2 = "C" if real(substr(nace_2,1,2))>8 & real(substr(nace_2,1,2))<33
replace nace_2 = "D" if nace_2=="35"
replace nace_2 = "E" if nace_2=="36_to_39"
replace nace_2 = "G" if nace_2=="45_to_46" | nace_2=="47"
replace nace_2 = "H" if inlist(nace_2,"49_to_52","53")
replace nace_2 = "J" if inlist(nace_2,"58_to_60","61_to_63")
replace nace_2 = "K" if strpos(nace_2,"64")!=0
replace nace_2 = "M" if strpos(nace_2,"68")!=0 | inlist(nace_2,"70","71")
replace nace_2 = "N" if inrange(real(substr(nace_2,1,2)),77,83)
replace nace_2 = "Q" if strpos(nace_2,"86")!=0 
replace nace_2 = "R" if strpos(nace_2,"90")!=0 
replace nace_2 = "S" if nace_2=="94"

gen industry = 1 		if nace_2!=""
replace industry = 2	if inlist(nace_2,"B","C","D","E")
replace industry = 3	if nace_2=="F"
replace industry = 4	if nace_2>"F" & nace_2 <"O" 
replace industry = 5	if nace_2>"M" & nace_2!=""

label_inds	
	
save , replace	
