*===================================*
*		Job characteristics			*
*===================================* 

* Recovers variables concerning job and industry
* For the occupation, 3 digit codes are optional + revision in 2008
 
version 14

cd "$dofiles"
global dofiles  "`c(pwd)'"
global original "$dofiles\..\original data\"
global correct 	"$dofiles\..\data"


cd "$correct"

local files: dir . files "*.dta"
foreach file in `files'{
		
	tokenize `file', parse("_",".")
	local yy 		"`5'"
	local cc 	"`7'"
	
	use "`file'", clear
	
	
	* Occupation 
	*-------------------->
	
	capture drop isco?????
	if `yy' <2010{
		cap unique b23
		if r(sum) > 50{		
			gen isco88_3d = b23
			gen isco88_2d = floor(b23/10)
		}
		else{		
			gen isco88_3d = .
			gen isco88_2d = b23
		}
	}
	
	if `yy' >2006{
		cap unique b23
		if r(sum) > 50{		
			gen isco08_3d = b23
			gen isco08_2d = floor(b23/10)
		}
		else{		
			gen isco08_3d = .
			gen isco08_2d = b23
		}
	}
	
	* Job characteristics
	*--------------------------->
	
	capture drop cont_type
	capture drop indef
	capture confirm string variable b28
	if !_rc {
	gen cont_type 		= "Open-ended" 		if b28=="A"
	replace cont_type 	= "Temporary-fix"	if b28=="B"
	replace cont_type 	= "Apprenticeship"	if b28=="C"
	
	gen indef = b28=="A"
	}
	else{
	gen cont_type = ""
	gen indef =0
	}

	label var cont_type "Type of contract"

		
	capture drop ft
	gen ft = b27=="FT"
	label var ft "Full-time position"
	
	capture drop part
	gen part= b27 =="PT"
	
	
	capture drop manager
	gen manager = b24=="Y" if strlen(b24)!=3
	label var manager "has managerial responsibilities"
	
	if !inlist("`cc'","germany", "sweden") {
	gen no_col = a15=="N" if !missing(a15) & a15!= " "
	}
	if "`cc'"=="germany" {
	gen no_col = a15==0 if !missing(a15) 
	}
	if "`cc'"=="sweden" {
	gen no_col = 0  // No information for Sweden
	}

	label var no_col "No collective agreements for wage bargaining"
	save, replace
	
}
 
